/* Open Source License

Copyright 2005 by Frank McCown
All rights reserved.

Developed by:  Frank McCown
               Old Dominion University
               http://www.cs.odu.edu/~fmccown

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal with the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

         - Redistributions of source code must retain the above copyright
           notice, this list of conditions and the following disclaimers.
         - Redistributions in binary form must reproduce the above copyright
           notice, this list of conditions and the following disclaimers in the
           documentation and/or other materials provided with the distribution.
         - Neither the names of Open Archives Initiative Metadata Harvesting
           Project, Old Dominion University, nor the names of
           its contributors may be used to endorse or promote products derived
           from this Software without specific prior written permission.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS WITH THE SOFTWARE.

*/

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

namespace oaidemo
{
	/// <summary>
	/// Summary description for ListMetadataFormats.
	/// </summary>
	public class ListMetadataFormats : System.Web.UI.Page
	{
		protected string errorMessage = null;
		protected string identifier = null;


		private void VerifyIdentifier()
		{
			string scheme, namespaceIdentifier, localIdentifier;
			bool ret = Util.ParseOAIIdentifier(identifier, out scheme, out namespaceIdentifier, out localIdentifier);
            
			if (!ret || (scheme != "oai") || (namespaceIdentifier != (string)Application["NamespaceIdentifier"]))
			{
				errorMessage = @"<error code=""idDoesNotExist"">identifier is not valid.</error>";
				return;
			}

			DataSet ds = (DataSet)Application["RecordsDataSet"];

			DataRow[] rows = ds.Tables["record"].Select("id = '" + localIdentifier + "'");
			if (rows.Length == 0)
			{
				errorMessage = @"<error code=""idDoesNotExist"">identifier '" + Server.HtmlEncode(identifier) + "' not found.</error>";
				return;
			}			
		}
		
		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);


			// There are no required parameters, "identifier" is an optional param

			int numKeys = Request.QueryString.Count + Request.Form.Count;

			if (numKeys == 2)
			{
				// One of these must be the identifier
				identifier = Request["identifier"];
				if (identifier == null)
				{
					// Must be something besides "identifier" and "verb"
					errorMessage = @"<error code=""badArgument"">Illegal argument.  Only identifier may be supplied with verb.</error>";
				}
				else if (identifier.Length == 0)
				{
					errorMessage = @"<error code=""badArgument"">Content of argument 'identifier' is missing.</error>";
				}
				else if (!Util.CheckId(identifier))
				{
					errorMessage = @"<error code=""badArgument"">Identifier '" + identifier + "' is not a valid URI.</error>";
				}
				else
				{
					VerifyIdentifier();
				}
			}
			else if (numKeys > 2)
			{
				// Additional garbage was supplied
				errorMessage = @"<error code=""badArgument"">Illegal argument.  Only identifier may be supplied with verb.</error>";
			}
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    

		}
		#endregion
	}
}
